package common.tags;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

public abstract class Tag {
	protected static Tag createNewByType(byte id) {
		switch(id) {
			case 0:
				return new TagNull();
			case 1:
				return new TagByte();
			case 2:
				return new TagShort();
			case 3:
				return new TagInt();
			case 4:
				return new TagLong();
			case 5:
				return new TagFloat();
			case 6:
				return new TagDouble();
			case 7:
				return new TagByteArray();
			case 8:
				return new TagString();
			case 9:
				return new TagStringList();
			case 10:
				return new TagObject();
			case 11:
				return new TagIntArray();
			case 12:
				return new TagObjectList();
			case 13:
				return new TagFloatList();
			case 14:
				return new TagDoubleList();
			case 15:
				return new TagIntArrayList();
			default:
				return null;
		}
	}

	abstract void write(DataOutput output) throws IOException;
	abstract void read(DataInput input, int depth, SizeTracker tracker) throws IOException;
	public abstract String toString();
	protected abstract byte getId();
	public abstract Tag copy();

	public boolean equals(Object other) {
		return other instanceof Tag && this.getId() == ((Tag)other).getId();
	}

	public int hashCode() {
		return this.getId();
	}
}
