package common.tags;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.DataInput;
import java.io.DataInputStream;
import java.io.DataOutput;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.zip.GZIPInputStream;
import java.util.zip.GZIPOutputStream;

/**
 * compressed data tree / CDT loader
 * (ids 0..15)
 */
public class TagLoader {
	public static TagObject readGZip(File file) throws IOException {
		DataInputStream in = new DataInputStream(new BufferedInputStream(new GZIPInputStream(new FileInputStream(file))));
		TagObject tag;
		try {
			tag = read(in, SizeTracker.INFINITE);
		}
		finally {
			in.close();
		}
		return tag;
	}

	public static void writeGZip(TagObject tag, File file) throws IOException {
		DataOutputStream out = new DataOutputStream(new BufferedOutputStream(new GZIPOutputStream(new FileOutputStream(file))));
		try {
			write(tag, out);
		}
		finally {
			out.close();
		}
	}

	public static TagObject read(DataInput in, SizeTracker tracker) throws IOException {
		TagObject tag = new TagObject();
		tag.read(in, 0, tracker);
		return tag;
	}

	public static void write(TagObject tag, DataOutput out) throws IOException {
		tag.write(out);
	}
}
